/* gvSIG. Geographic Information System of the Valencian Government
 *
 * Copyright (C) 2007-2008 Infrastructures and Transports Department
 * of the Valencian Government (CIT)
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
 * MA  02110-1301, USA.
 * 
 */

package org.gvsig.fortunecookies.app.extension;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JToolBar;

import org.gvsig.andami.plugins.Extension;
import org.gvsig.fortunecookies.FortuneCookieLocator;
import org.gvsig.fortunecookies.FortuneCookieManager;
import org.gvsig.fortunecookies.FortuneCookieService;
import org.gvsig.fortunecookies.swing.FortuneCookieSwingLocator;
import org.gvsig.fortunecookies.swing.FortuneCookieUIManager;
import org.gvsig.fortunecookies.swing.FortuneCookieWindowManager;
import org.gvsig.fortunecookies.swing.JFortuneCookieServicePanel;
import org.gvsig.tools.dynobject.DynObject;
import org.gvsig.tools.library.impl.DefaultLibrariesInitializer;
import org.gvsig.tools.service.ServiceException;

public class FortuneCookieExtension extends Extension {

	FortuneCookieManager manager;
	FortuneCookieUIManager uimanager;
		
	public void execute(String actionCommand) {

		org.apache.log4j.BasicConfigurator.configure();
		
		new DefaultLibrariesInitializer().fullInitialize();
		manager = FortuneCookieLocator.getManager();
				
		//  Asignamos el locator e iniciamos la instancia
		uimanager = FortuneCookieSwingLocator.getUIManager();
		//manager = uimanager.getManager();
		
		
		JFrame frame = new JFrame("Fortune Cookie");
		
		// Create the menu bar.
		JMenuBar menuBar = new JMenuBar();

		// Build the menu.
		JMenu menu_file = new JMenu("File");
		JMenuItem menuItem_get = new JMenuItem("Get a fortune cookie");
		menuItem_get.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				showFortuneCookie(manager);
			}
	    });
		menu_file.add(menuItem_get);

	
		JMenuItem menuItem_exit = new JMenuItem("Exit");
		menuItem_exit.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e) {
				System.exit(0);
			}
	    });
		menu_file.add(menuItem_exit);
		
		menuBar.add(menu_file);
		
		JToolBar toolBar = new JToolBar();
		
		JButton get = new JButton("Get a fortune cookie");
		get.addActionListener(new ActionListener(){

			public void actionPerformed(ActionEvent arg0) {
				showFortuneCookie(manager);			
			}
			
		});
		toolBar.add(get);

		frame.setPreferredSize(new Dimension(160, 100));
		frame.add(menuBar, BorderLayout.NORTH);
		frame.add(toolBar, BorderLayout.LINE_END);
		
        //Display the window.
        frame.pack();
        frame.setVisible(true);
        		
	}
	
	public void showFortuneCookie(FortuneCookieManager manager) {
		try {
			DynObject parameters = manager.createServiceParameters("FortuneCookie.providers.web");
			FortuneCookieService service = (FortuneCookieService) manager.getService(parameters);
			JFortuneCookieServicePanel panel = uimanager.createFortuneCookie(service);
			uimanager.getWindowManager().showWindow(
					panel, 
					"Fortune Cookie", 
					FortuneCookieWindowManager.MODE_WINDOW
			);

		} catch (ServiceException e) {
			e.printStackTrace();
		}
	}

	
	public void initialize() {
		// Do nothing

	}

	public boolean isEnabled() {
		return true;
	}

	public boolean isVisible() {
		return true;
	}

}
