/* gvSIG. Geographic Information System of the Valencian Government
 *
 * Copyright (C) 2007-2008 Infrastructures and Transports Department
 * of the Valencian Government (CIT)
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
 * MA  02110-1301, USA.
 * 
 */

package org.gvsig.fortunecookies.impl;

import java.util.Date;

import org.gvsig.fortunecookies.FortuneCookieService;
import org.gvsig.fortunecookies.exception.FortuneCookieMessageException;
import org.gvsig.fortunecookies.lib.spi.FortuneCookieProvider;
import org.gvsig.tools.dynobject.DynObject;
import org.gvsig.tools.service.AbstractService;
import org.gvsig.tools.service.Manager;
import org.gvsig.tools.service.ServiceException;
import org.gvsig.tools.service.spi.AbstractProviderServices;
import org.gvsig.tools.service.spi.ProviderManager;

public class DefaultFortuneCookieService extends AbstractService implements FortuneCookieService{

	private String message;
	private DefaultFortuneCookieManager manager;
	private Date date = null;
	
	public DefaultFortuneCookieService(DefaultFortuneCookieManager manager, DynObject parameters, AbstractProviderServices providerServices) throws ServiceException {
		this.manager = manager;
		this.message = null;
		this.init(parameters, providerServices);
	}
	

	public String getMessage() throws FortuneCookieMessageException {
		if(message==null){
			FortuneCookieProvider provider = (FortuneCookieProvider)this.getProvider();
			try {
				this.message = provider.getMessage();
			} catch (Exception e) {
				throw new FortuneCookieMessageException(e);
			}
			this.date = new Date();
		}
		return this.message;
	}

	
	/*
	 * (non-Javadoc)
	 * @see org.gvsig.tools.service.Service#getProviderManager()
	 * 
	 * This method must be implemented in all Services
	 */
	protected ProviderManager getProviderManager() {
		return this.manager.getProviderManager();
	}

	/*
	 * (non-Javadoc)
	 * @see org.gvsig.tools.service.Service#getManager()
	 * 
	 * This method must be implemented in all Services
	 */
	public Manager getManager() {
		return this.manager;
	}
	
	public Date getDate() {
		return this.date;
	}

	public String getProviderInfo() {
		return this.getProvider().toString();
	}

}
