/* gvSIG. Geographic Information System of the Valencian Government
 *
 * Copyright (C) 2007-2008 Infrastructures and Transports Department
 * of the Valencian Government (CIT)
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
 * MA  02110-1301, USA.
 * 
 */

package org.gvsig.fortunecookies.swing;


import org.gvsig.fortunecookies.FortuneCookieManager;
import org.gvsig.fortunecookies.FortuneCookieService;
import org.gvsig.tools.service.Service;

/**
 * 
 * This class is responsible of the management of the user's interface role from the FortuneCookie application
 *
 * @see FortuneCookieService
 * @see FortuneCookieManager
 */
public interface FortuneCookieUIManager{
	
	/**
	 * Returns the panel associated to a {@link FortuneCookieService}
	 * 
	 * @param {@link FortuneCookieService} contained on the panel
	 *    
	 * @return a {@link JFortuneCookieServicePanel} with the panel of the {@link FortuneCookieService}
	 * 
	 * @see JFortuneCookieServicePanel
	 * @see FortuneCookieService
	 */
	public JFortuneCookieServicePanel createFortuneCookie(FortuneCookieService cookie);	
	
	/**
	 * Returns the panel associated to a {@link Service}
	 * 
	 * @param {@link Service} contained on the panel
	 *    
	 * @return a {@link JFortuneCookieServicePanel} with the panel of the {@link Service}
	 * 
	 * @see JFortuneCookieServicePanel
	 * @see Service
	 */
	public JFortuneCookieServicePanel createFortuneCookie(Service cookie);
	
	/**
	 * Returns the {@link FortuneCookieManager}
	 *    
	 * @return {@link FortuneCookieManager}
	 * 
	 * @see {@link FortuneCookieManager}
	 */
	public FortuneCookieManager getManager();

	/**
	 * Returns the translation of a string
	 * 
	 * @param string String to translate
	 *    
	 * @return a String with the translation of the string passed by parameter
	 */
	public String getTranslation(String string);
		
	/**
	 * Registers a new instance of a WindowManager which provides services to the management of the application windows
	 *
	 * @params manager {@link  FortuneCookieWindowManager} to register in the ScriptingUIManager.
	 * 
	 * @see FortuneCookieWindowManager
	 */
	public void registerWindowManager(FortuneCookieWindowManager manager);
	
	/**
	 * Returns the {@link FortuneCookieWindowManager}
	 *    
	 * @return {@link FortuneCookieWindowManager}
	 * 
	 * @see {@link FortuneCookieWindowManager}
	 */
	public FortuneCookieWindowManager getWindowManager();
}