/* gvSIG. Geographic Information System of the Valencian Government
 *
 * Copyright (C) 2007-2008 Infrastructures and Transports Department
 * of the Valencian Government (CIT)
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
 * MA  02110-1301, USA.
 * 
 */

package org.gvsig.fortunecookies.swing.impl;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;

import org.gvsig.fortunecookies.FortuneCookieService;
import org.gvsig.fortunecookies.exception.FortuneCookieMessageException;
import org.gvsig.fortunecookies.swing.FortuneCookieUIManager;
import org.gvsig.fortunecookies.swing.FortuneCookieWindowManager;
import org.gvsig.fortunecookies.swing.JFortuneCookieServicePanel;


public class DefaultJFortuneCookieServicePanel extends JFortuneCookieServicePanel{

	/**
	 * 
	 */
	private static final long serialVersionUID = 2965442763236823977L;
	private FortuneCookieService cookie;
	protected JButton accept = null;
	protected JButton info = null;	
	private FortuneCookieUIManager uimanager;


	public DefaultJFortuneCookieServicePanel(DefaultFortuneCookieUIManager uimanager, FortuneCookieService cookie) {
	
		this.cookie = cookie;
		this.uimanager = uimanager;
		
		this.setLayout(new BorderLayout());
		this.setPreferredSize(new Dimension(550,150));

		JTextArea text = new JTextArea();
		try {
			text.setText(cookie.getMessage());
		} catch (FortuneCookieMessageException e) {
			text.setText(this.uimanager.getTranslation("Error obtaining message....."));
			e.printStackTrace();
		}
		text.setEditable(false);
		
	    JScrollPane scrollPane = new JScrollPane(text);
	    scrollPane.setPreferredSize(new Dimension(550, 150));

	    accept = new JButton(this.uimanager.getTranslation("Accept"));
	    info = new JButton(this.uimanager.getTranslation("Info"));
		
		JPanel optionsPane = new JPanel();
		optionsPane.setLayout(new BoxLayout(optionsPane, BoxLayout.LINE_AXIS));
		optionsPane.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));
		optionsPane.add(Box.createHorizontalGlue());
		
		accept.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent arg0) {
				setVisible(false);
			}
		});
		info.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent arg0) {
				showInfo();
			}
		});
		
		optionsPane.add(accept);
		optionsPane.add(info);
		optionsPane.add(Box.createRigidArea(new Dimension(10, 0)));
		
		this.add(scrollPane, BorderLayout.CENTER);
		this.add(optionsPane, BorderLayout.SOUTH);
	}

	private void showInfo() {
		JPanel infoPanel = new DefaultJFortuneCookieServiceInfoPanel(this.uimanager, this.cookie);
		this.uimanager.getWindowManager().showWindow(
				infoPanel, 
				this.uimanager.getTranslation("Information"), 
				FortuneCookieWindowManager.MODE_DIALOG
		);
	}

	@Override
	public FortuneCookieService getFortuneCookie() {
		return cookie;
	}
	
}
